@@ -19,6 +19,7 @@
  * @author Christian Grothoff
  */
 #include "platform.h"
+#include "microhttpd.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <pthread.h>
@@ -423,6 +424,7 @@ deposit_get_cb (
   case MHD_HTTP_OK:
     {
       enum GNUNET_DB_QueryStatus qs;
+      bool cleared = false;
 
       GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                   "Exchange returned wire transfer over %s for deposited coin %s\n",
@@ -431,7 +433,24 @@ deposit_get_cb (
       qs = db_plugin->insert_deposit_to_transfer (
         db_plugin->cls,
         w->deposit_serial,
-        &dr->details.ok);
+        &dr->details.ok,
+        &cleared);
+      if (qs < 0)
+      {
+        GNUNET_break (0);
+        GNUNET_SCHEDULER_shutdown ();
+        return;
+      }
+      if (! cleared)
+      {
+        qs = db_plugin->update_deposit_confirmation_status (
+          db_plugin->cls,
+          w->deposit_serial,
+          true, /* this failed, wire_pending remains true */
+          GNUNET_TIME_absolute_to_timestamp (future_retry),
+          w->retry_backoff,
+          "wire transfer unknown");
+      }
       if (qs < 0)
       {
         GNUNET_break (0);
@@ -589,8 +608,7 @@ pending_deposits_cb (
   const struct TALER_Amount *deposit_fee,
   const struct TALER_CoinSpendPublicKeyP *coin_pub)
 {
-  struct ExchangeInteraction *w
-    = GNUNET_new (struct ExchangeInteraction);
+  struct ExchangeInteraction *w;
 
   (void) cls;
   if (GNUNET_TIME_absolute_is_future (wire_deadline))
@@ -601,6 +619,7 @@ pending_deposits_cb (
     run_at (wire_deadline);
     return;
   }
+  w = GNUNET_new (struct ExchangeInteraction);
   w->deposit_serial = deposit_serial;
   w->wire_deadline = wire_deadline;
   w->retry_backoff = GNUNET_TIME_STD_BACKOFF (retry_backoff);
@@ -750,7 +769,21 @@ start_worker (const char *base_url)
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Launching worker for exchange `%s' using `%s`\n",
               base_url,
-              cfg_filename);
+              NULL == cfg_filename
+              ? "<default>"
+              : cfg_filename);
+  if (NULL == cfg_filename)
+    return GNUNET_OS_start_process (
+      GNUNET_OS_INHERIT_STD_ALL,
+      NULL,
+      NULL,
+      NULL,
+      "taler-merchant-depositcheck",
+      "taler-merchant-depositcheck",
+      "-e", base_url,
+      "-L", "INFO",
+      test_mode ? "-t" : NULL,
+      NULL);
   return GNUNET_OS_start_process (
     GNUNET_OS_INHERIT_STD_ALL,
     NULL,
@@ -917,6 +950,7 @@ update_exchange_keys (void *cls,
 
   {
     enum GNUNET_DB_QueryStatus qs;
+    struct GNUNET_TIME_Absolute earliest_retry;
 
     if (NULL != keys)
     {
@@ -925,6 +959,7 @@ update_exchange_keys (void *cls,
     }
     qs = db_plugin->select_exchange_keys (db_plugin->cls,
                                           exchange_url,
+                                          &earliest_retry,
                                           &keys);
     if (qs < 0)
     {
@@ -973,7 +1008,8 @@ run (void *cls,
   (void) args;
 
   cfg = c;
-  cfg_filename = GNUNET_strdup (cfgfile);
+  if (NULL != cfgfile)
+    cfg_filename = GNUNET_strdup (cfgfile);
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Running with configuration %s\n",
               cfgfile);
