@@ -518,7 +518,7 @@ TMH_lookup_instance (const char *instance_id)
   struct GNUNET_HashCode h_instance;
 
   if (NULL == instance_id)
-    instance_id = "default";
+    instance_id = "admin";
   GNUNET_CRYPTO_hash (instance_id,
                       strlen (instance_id),
                       &h_instance);
@@ -547,7 +547,7 @@ TMH_add_instance (struct TMH_MerchantInstance *mi)
 
   id = mi->settings.id;
   if (NULL == id)
-    id = "default";
+    id = "admin";
   GNUNET_CRYPTO_hash (id,
                       strlen (id),
                       &mi->h_instance);
@@ -619,7 +619,7 @@ spa_redirect (const struct TMH_RequestHandler *rh,
                                          MHD_HTTP_HEADER_CONTENT_TYPE,
                                          "text/plain"));
   if ( (NULL == hc->instance) ||
-       (0 == strcmp ("default",
+       (0 == strcmp ("admin",
                      hc->instance->settings.id)) )
     dst = GNUNET_strdup ("/webui/");
   else
@@ -1345,7 +1345,7 @@ url_handler (void *cls,
   };
   static struct TMH_RequestHandler public_handlers[] = {
     {
-      /* for "default" instance, it does not even
+      /* for "admin" instance, it does not even
          have to exist before we give the WebUI */
       .url_prefix = "/",
       .method = MHD_HTTP_METHOD_GET,
@@ -1598,7 +1598,7 @@ url_handler (void *cls,
         instance_id = GNUNET_strndup (istart,
                                       slash - istart);
       if (0 == strcmp (instance_id,
-                       "default"))
+                       "admin"))
       {
         MHD_RESULT ret;
         struct MHD_Response *response;
@@ -1622,20 +1622,22 @@ url_handler (void *cls,
         {
           GNUNET_break (0);
           MHD_destroy_response (response);
+          GNUNET_free (instance_id);
           return MHD_NO;
         }
         ret = MHD_queue_response (connection,
                                   MHD_HTTP_PERMANENT_REDIRECT,
                                   response);
         MHD_destroy_response (response);
+        GNUNET_free (instance_id);
         return ret;
       }
       hc->instance = TMH_lookup_instance (instance_id);
       if ( (NULL == hc->instance) &&
-           (0 == strcmp ("default",
+           (0 == strcmp ("admin",
                          instance_id)) )
         hc->instance = TMH_lookup_instance (NULL);
-      if ( (0 == strcmp ("default",
+      if ( (0 == strcmp ("admin",
                          instance_id)) &&
            (NULL != TMH_default_auth) &&
            (NULL != hc->instance) )
