@@ -520,6 +520,8 @@ TMH_EXCHANGES_keys4exchange (
        (NULL != exchange->keys) )
   {
     /* Return results immediately. */
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Earliest retry is in the future, returning keys now\n");
     fo->at = GNUNET_SCHEDULER_add_now (&return_keys,
                                        fo);
     /* *no* return here, we MAY schedule a 'retry_task' in the
@@ -674,11 +676,7 @@ TMH_exchange_check_debit (
   struct TALER_Amount *max_amount)
 {
   const struct TALER_EXCHANGE_Keys *keys = exchange->keys;
-  struct TALER_NormalizedPayto np;
-  bool account_ok;
   bool have_kyc = false;
-  struct TALER_Amount kyc_limit;
-  bool unlimited = true;
   bool no_access_token = true;
 
   if (NULL == keys)
@@ -693,15 +691,22 @@ TMH_exchange_check_debit (
                 max_amount->currency);
     return GNUNET_SYSERR;
   }
-
-  np = TALER_payto_normalize (wm->payto_uri);
-  account_ok = TALER_EXCHANGE_keys_test_account_allowed (keys,
-                                                         false,
-                                                         np);
-  GNUNET_free (np.normalized_payto);
-  if (keys->kyc_enabled)
   {
-    bool kyc_ok = false;
+    struct TALER_NormalizedPayto np;
+    bool account_ok;
+
+    np = TALER_payto_normalize (wm->payto_uri);
+    account_ok = TALER_EXCHANGE_keys_test_account_allowed (keys,
+                                                           false,
+                                                           np);
+    GNUNET_free (np.normalized_payto);
+    if (! account_ok)
+      return GNUNET_NO;
+  }
+  if (! keys->kyc_enabled)
+    return GNUNET_YES;
+
+  {
     json_t *jlimits = NULL;
     enum GNUNET_DB_QueryStatus qs;
 
@@ -709,7 +714,7 @@ TMH_exchange_check_debit (
                                  wm->payto_uri,
                                  instance_id,
                                  exchange->url,
-                                 &kyc_ok,
+                                 &have_kyc,
                                  &no_access_token,
                                  &jlimits);
     GNUNET_break (qs >= 0);
@@ -717,13 +722,15 @@ TMH_exchange_check_debit (
                 "get_kyc_limits for %s at %s returned %s/%s\n",
                 wm->payto_uri.full_payto,
                 exchange->url,
-                kyc_ok ? "KYC OK" : "KYC missing",
+                have_kyc ? "KYC OK" : "KYC missing",
                 NULL == jlimits ? "default limits" : "custom limits");
     if ( (qs > 0) &&
          (NULL != jlimits) )
     {
       json_t *jlimit;
       size_t idx;
+      struct TALER_Amount kyc_limit;
+      bool unlimited = true;
 
       json_array_foreach (jlimits, idx, jlimit)
       {
@@ -772,64 +779,62 @@ TMH_exchange_check_debit (
         }
       }
       json_decref (jlimits);
-    }
-    if (kyc_ok)
-      have_kyc = true;
+      /* We had custom rules, do not evaluate default rules */
+      if (! unlimited)
+        TALER_amount_min (max_amount,
+                          max_amount,
+                          &kyc_limit);
+      return GNUNET_YES;
+    } /* END of if qs > 0, NULL != jlimits */
   }
 
-  if (! unlimited)
-    TALER_amount_min (max_amount,
-                      max_amount,
-                      &kyc_limit);
-  if (keys->kyc_enabled)
-  {
-    /* apply both deposit and transaction limits */
-    if ( (no_access_token) ||
-         ( (! have_kyc) &&
-           (TALER_EXCHANGE_keys_evaluate_zero_limits (
-              keys,
-              TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT) ||
-            TALER_EXCHANGE_keys_evaluate_zero_limits (
-              keys,
-              TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION)) ) )
-    {
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "KYC requirements of %s not satisfied\n",
-                  exchange->url);
-      GNUNET_assert (GNUNET_OK ==
-                     TALER_amount_set_zero (
-                       max_amount->currency,
-                       max_amount));
-    }
-    else
-    {
-      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                  "Evaluating default limits of %s\n",
-                  exchange->url);
-      TALER_EXCHANGE_keys_evaluate_hard_limits (
-        keys,
-        TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT,
-        max_amount);
-      TALER_EXCHANGE_keys_evaluate_hard_limits (
-        keys,
-        TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION,
-        max_amount);
-      if (TALER_EXCHANGE_keys_evaluate_zero_limits (
+  /* Check zero limits *only* if we did no KYC process at all yet.
+     Because if we did, there is at least a chance that those have
+     been lifted. */
+  if ( (no_access_token) ||
+       ( (! have_kyc) &&
+         (TALER_EXCHANGE_keys_evaluate_zero_limits (
             keys,
             TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT) ||
           TALER_EXCHANGE_keys_evaluate_zero_limits (
             keys,
-            TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION))
-      {
-        GNUNET_log (GNUNET_ERROR_TYPE_INFO,
-                    "Operation is zero-limited by default\n");
-        GNUNET_assert (GNUNET_OK ==
-                       TALER_amount_set_zero (max_amount->currency,
-                                              max_amount));
-      }
-    }
+            TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION)) ) )
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "KYC requirements of %s not satisfied\n",
+                exchange->url);
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_amount_set_zero (
+                     max_amount->currency,
+                     max_amount));
+    return GNUNET_YES;
   }
-  return account_ok ? GNUNET_YES : GNUNET_NO;
+  /* In any case, abide by hard limits (unless we have custom rules). */
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Evaluating default hard limits of %s\n",
+              exchange->url);
+  TALER_EXCHANGE_keys_evaluate_hard_limits (
+    keys,
+    TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT,
+    max_amount);
+  TALER_EXCHANGE_keys_evaluate_hard_limits (
+    keys,
+    TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION,
+    max_amount);
+  if (TALER_EXCHANGE_keys_evaluate_zero_limits (
+        keys,
+        TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT) ||
+      TALER_EXCHANGE_keys_evaluate_zero_limits (
+        keys,
+        TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION))
+  {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Operation is zero-limited by default\n");
+    GNUNET_assert (GNUNET_OK ==
+                   TALER_amount_set_zero (max_amount->currency,
+                                          max_amount));
+  }
+  return GNUNET_YES;
 }
 
 
@@ -885,9 +890,11 @@ reload_exchange_keys (struct TMH_Exchange *exchange)
 {
   enum GNUNET_DB_QueryStatus qs;
   struct TALER_EXCHANGE_Keys *keys;
+  struct GNUNET_TIME_Absolute first_retry;
 
   qs = TMH_db->select_exchange_keys (TMH_db->cls,
                                      exchange->url,
+                                     &first_retry,
                                      &keys);
   if (qs < 0)
   {
@@ -901,7 +908,11 @@ reload_exchange_keys (struct TMH_Exchange *exchange)
                 exchange->url);
     return;
   }
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Loading latest keys of `%s' from database\n",
+              exchange->url);
   exchange->retry_delay = GNUNET_TIME_UNIT_ZERO;
+  exchange->first_retry = first_retry;
   if (NULL == exchange->currency)
     exchange->currency = GNUNET_strdup (keys->currency);
   if (0 != strcmp (keys->currency,
@@ -1191,6 +1202,7 @@ TMH_EXCHANGES_init (const struct GNUNET_CONFIGURATION_Handle *cfg)
       .type = ntohs (TALER_DBEVENT_MERCHANT_EXCHANGE_KEYS)
     };
 
+    GNUNET_assert (NULL == keys_eh);
     keys_eh = TMH_db->event_listen (TMH_db->cls,
                                     &es,
                                     GNUNET_TIME_UNIT_FOREVER_REL,
