@@ -302,11 +302,8 @@ suspend_god (struct GetOrderData *god)
   if (NULL != god->contract_terms_json)
   {
     json_decref (god->contract_terms_json);
-    god->contract_terms->fulfillment_url = NULL;
     god->contract_terms_json = NULL;
     god->contract_parsed = false;
-    god->contract_terms->merchant_base_url = NULL;
-    god->contract_terms->public_reorder_url = NULL;
   }
   if (NULL != god->contract_terms)
   {
@@ -731,6 +728,7 @@ phase_lookup_terms (struct GetOrderData *god)
 static void
 phase_parse_contract (struct GetOrderData *god)
 {
+  GNUNET_break (NULL == god->contract_terms);
   god->contract_terms = TALER_MERCHANT_contract_parse (
     god->contract_terms_json,
     true);
@@ -1613,10 +1611,10 @@ TMH_get_orders_ID (const struct TMH_RequestHandler *rh,
                                       "token",
                                       &god->claim_token,
                                       god->claim_token_provided);
-    if (! (TALER_arg_to_yna (connection,
-                             "allow_refunded_for_repurchase",
-                             TALER_EXCHANGE_YNA_NO,
-                             &god->allow_refunded_for_repurchase)) )
+    if (! (TALER_MHD_arg_to_yna (connection,
+                                 "allow_refunded_for_repurchase",
+                                 TALER_EXCHANGE_YNA_NO,
+                                 &god->allow_refunded_for_repurchase)) )
       return TALER_MHD_reply_with_error (connection,
                                          MHD_HTTP_BAD_REQUEST,
                                          TALER_EC_GENERIC_PARAMETER_MALFORMED,
