@@ -803,7 +803,7 @@ TMH_base_url_by_connection (struct MHD_Connection *connection,
                                 uri_path);
   }
   if (0 != strcmp (instance,
-                   "default"))
+                   "admin"))
   {
     GNUNET_buffer_write_path (buf,
                               "/instances/");
@@ -870,7 +870,7 @@ TMH_taler_uri_by_connection (struct MHD_Connection *connection,
   if (NULL != uri_path)
     GNUNET_buffer_write_path (buf,
                               uri_path);
-  if (0 != strcmp ("default",
+  if (0 != strcmp ("admin",
                    instance))
   {
     GNUNET_buffer_write_path (buf,
