@@ -272,7 +272,7 @@ TMH_post_orders_ID_claim (const struct TMH_RequestHandler *rh,
   /* create contract signature */
   {
     struct TALER_PrivateContractHashP hash;
-    struct GNUNET_CRYPTO_EddsaSignature merchant_sig;
+    struct TALER_MerchantSignatureP merchant_sig;
 
     /**
      * Hash of the JSON contract in UTF-8 including 0-termination,
