@@ -91,6 +91,7 @@ TMH_post_orders_ID_paid (const struct TMH_RequestHandler *rh,
   const char *order_id = hc->infix;
   struct TALER_MerchantSignatureP merchant_sig;
   const char *session_id;
+  int16_t choice_index;
   struct TALER_PrivateContractHashP hct;
   json_t *contract_terms;
   const char *fulfillment_url;
@@ -104,10 +105,15 @@ TMH_post_orders_ID_paid (const struct TMH_RequestHandler *rh,
                                    &hct),
       GNUNET_JSON_spec_string ("session_id",
                                &session_id),
+      GNUNET_JSON_spec_mark_optional (
+        GNUNET_JSON_spec_int16 ("choice_index",
+                                &choice_index),
+        NULL),
       GNUNET_JSON_spec_end ()
     };
     enum GNUNET_GenericReturnValue res;
 
+    choice_index = -1;
     res = TALER_MHD_parse_json_data (connection,
                                      hc->request_body,
                                      spec);
@@ -202,7 +208,8 @@ TMH_post_orders_ID_paid (const struct TMH_RequestHandler *rh,
   qs = TMH_db->mark_contract_paid (TMH_db->cls,
                                    hc->instance->settings.id,
                                    &hct,
-                                   session_id);
+                                   session_id,
+                                   choice_index);
   /* If the order was paid already, we get qs == 0. */
   if (0 > qs)
   {
