@@ -20,28 +20,32 @@
  */
 #include "platform.h"
 #include "taler-merchant-httpd_private-get-accounts.h"
+#include <taler/taler_json_lib.h>
 
 
 /**
  * Add account details to our JSON array.
  *
  * @param cls a `json_t *` JSON array to build
+ * @param merchant_priv private key of the merchant instance
  * @param ad details about the account
  */
 static void
 add_account (void *cls,
+             const struct TALER_MerchantPrivateKeyP *merchant_priv,
              const struct TALER_MERCHANTDB_AccountDetails *ad)
 {
   json_t *pa = cls;
 
+  (void) merchant_priv;
   GNUNET_assert (0 ==
                  json_array_append_new (
                    pa,
                    GNUNET_JSON_PACK (
                      GNUNET_JSON_pack_bool ("active",
                                             ad->active),
-                     GNUNET_JSON_pack_string ("payto_uri",
-                                              ad->payto_uri),
+                     TALER_JSON_pack_full_payto ("payto_uri",
+                                                 ad->payto_uri),
                      GNUNET_JSON_pack_data_auto ("h_wire",
                                                  &ad->h_wire))));
 }
