@@ -49,7 +49,7 @@ get_instances_ID (struct TMH_MerchantInstance *mi,
       json_array_append_new (
         ja,
         GNUNET_JSON_PACK (
-          GNUNET_JSON_pack_string (
+          TALER_JSON_pack_full_payto (
             "payto_uri",
             wm->payto_uri),
           GNUNET_JSON_pack_allow_null (
