@@ -18,20 +18,20 @@
  * @brief implementation of GET /private/orders/ID handler
  * @author Florian Dold
  * @author Christian Grothoff
+ * @author Bohdan Potuzhnyi
+ * @author Iván Ávalos
  */
 #include "platform.h"
-#include "taler-merchant-httpd_private-get-orders-ID.h"
-#include "taler-merchant-httpd_get-orders-ID.h"
-#include <gnunet/gnunet_json_lib.h>
-#include <jansson.h>
-#include <stdint.h>
 #include <taler/taler_json_lib.h>
 #include <taler/taler_dbevents.h>
-#include "taler-merchant-httpd_mhd.h"
-#include "taler-merchant-httpd_exchanges.h"
+#include <taler/taler_error_codes.h>
+#include <taler/taler_util.h>
+#include <gnunet/gnunet_common.h>
+#include <gnunet/gnunet_json_lib.h>
+#include "taler_merchant_util.h"
 #include "taler-merchant-httpd_helper.h"
 #include "taler-merchant-httpd_private-get-orders.h"
-
+#include "taler-merchant-httpd_private-get-orders-ID.h"
 
 /**
  * Data structure we keep for a check payment request.
@@ -205,13 +205,6 @@ struct GetOrderRequestContext
    */
   const char *session_id;
 
-  /**
-   * Fulfillment URL extracted from the contract. For repurchase detection.
-   * Only valid as long as @e contract_terms is valid!  NULL if there is
-   * no fulfillment URL in the contract.
-   */
-  const char *fulfillment_url;
-
   /**
    * Kept in a DLL while suspended on exchange.
    */
@@ -253,28 +246,23 @@ struct GetOrderRequestContext
    * Contract terms of the payment we are checking. NULL when they
    * are not (yet) known.
    */
-  json_t *contract_terms;
+  json_t *contract_terms_json;
+
+  /**
+   * Parsed contract terms, NULL when parsing failed
+   */
+  struct TALER_MERCHANT_Contract *contract_terms;
 
   /**
    * Claim token of the order.
    */
   struct TALER_ClaimTokenP claim_token;
 
-  /**
-   * Timestamp from the @e contract_terms.
-   */
-  struct GNUNET_TIME_Timestamp timestamp;
-
   /**
    * Timestamp of the last payment.
    */
   struct GNUNET_TIME_Timestamp last_payment;
 
-  /**
-   * Order summary. Pointer into @e contract_terms.
-   */
-  const char *summary;
-
   /**
    * Wire details for the payment, to be returned in the reply. NULL
    * if not available.
@@ -286,6 +274,11 @@ struct GetOrderRequestContext
    */
   json_t *refund_details;
 
+  /**
+   * Amount of the order, unset for unpaid v1 orders.
+   */
+  struct TALER_Amount contract_amount;
+
   /**
    * Hash over the @e contract_terms.
    */
@@ -308,11 +301,6 @@ struct GetOrderRequestContext
    */
   struct TALER_Amount value_total;
 
-  /**
-   * Total we were to be paid under the contract, excluding refunds.
-   */
-  struct TALER_Amount contract_amount;
-
   /**
    * Serial ID of the order.
    */
@@ -486,9 +474,24 @@ static void
 gorc_cleanup (void *cls)
 {
   struct GetOrderRequestContext *gorc = cls;
+  struct TransferQuery *tq;
 
+  while (NULL != (tq = gorc->tq_head))
+  {
+    GNUNET_CONTAINER_DLL_remove (gorc->tq_head,
+                                 gorc->tq_tail,
+                                 tq);
+    GNUNET_free (tq->exchange_url);
+    GNUNET_free (tq);
+  }
+
+  if (NULL != gorc->contract_terms_json)
+    json_decref (gorc->contract_terms_json);
   if (NULL != gorc->contract_terms)
-    json_decref (gorc->contract_terms);
+  {
+    TALER_MERCHANT_contract_free (gorc->contract_terms);
+    gorc->contract_terms = NULL;
+  }
   if (NULL != gorc->wire_details)
     json_decref (gorc->wire_details);
   if (NULL != gorc->refund_details)
@@ -563,7 +566,7 @@ phase_init (struct GetOrderRequestContext *gorc)
     &resume_by_event,
     gorc);
   if ( (NULL != gorc->session_id) &&
-       (NULL != gorc->fulfillment_url) )
+       (NULL != gorc->contract_terms->fulfillment_url) )
   {
     struct TMH_SessionEventP session_eh = {
       .header.size = htons (sizeof (session_eh)),
@@ -577,8 +580,8 @@ phase_init (struct GetOrderRequestContext *gorc)
     GNUNET_CRYPTO_hash (gorc->session_id,
                         strlen (gorc->session_id),
                         &session_eh.h_session_id);
-    GNUNET_CRYPTO_hash (gorc->fulfillment_url,
-                        strlen (gorc->fulfillment_url),
+    GNUNET_CRYPTO_hash (gorc->contract_terms->fulfillment_url,
+                        strlen (gorc->contract_terms->fulfillment_url),
                         &session_eh.h_fulfillment_url);
     gorc->session_eh
       = TMH_db->event_listen (
@@ -603,7 +606,7 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
   struct TMH_HandlerContext *hc = gorc->hc;
   enum GNUNET_DB_QueryStatus qs;
 
-  if (NULL != gorc->contract_terms)
+  if (NULL != gorc->contract_terms_json)
   {
     /* Free memory filled with old contract terms before fetching the latest
        ones from the DB.  Note that we cannot simply skip the database
@@ -612,10 +615,8 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
        invocation of this function and we are back here due to long polling)
        and thus the contract terms could have changed during claiming. Thus,
        we need to fetch the latest contract terms from the DB again. */
-    json_decref (gorc->contract_terms);
-    gorc->contract_terms = NULL;
-    gorc->fulfillment_url = NULL;
-    gorc->summary = NULL;
+    json_decref (gorc->contract_terms_json);
+    gorc->contract_terms_json = NULL;
     gorc->order_only = false;
   }
   TMH_db->preflight (TMH_db->cls);
@@ -623,7 +624,7 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
                                        hc->instance->settings.id,
                                        hc->infix,
                                        gorc->session_id,
-                                       &gorc->contract_terms,
+                                       &gorc->contract_terms_json,
                                        &gorc->order_serial,
                                        &gorc->paid,
                                        &gorc->wired,
@@ -672,7 +673,7 @@ phase_fetch_contract (struct GetOrderRequestContext *gorc)
                                hc->infix,
                                &gorc->claim_token,
                                &unused,
-                               &gorc->contract_terms);
+                               &gorc->contract_terms_json);
   }
   if (0 > qs)
   {
@@ -711,39 +712,74 @@ static void
 phase_parse_contract (struct GetOrderRequestContext *gorc)
 {
   struct TMH_HandlerContext *hc = gorc->hc;
-  struct GNUNET_JSON_Specification spec[] = {
-    TALER_JSON_spec_amount_any ("amount",
-                                &gorc->contract_amount),
-    GNUNET_JSON_spec_mark_optional (
-      GNUNET_JSON_spec_string ("fulfillment_url",
-                               &gorc->fulfillment_url),
-      NULL),
-    GNUNET_JSON_spec_string ("summary",
-                             &gorc->summary),
-    GNUNET_JSON_spec_timestamp ("timestamp",
-                                &gorc->timestamp),
-    GNUNET_JSON_spec_end ()
-  };
 
-  if (GNUNET_OK !=
-      GNUNET_JSON_parse (gorc->contract_terms,
-                         spec,
-                         NULL, NULL))
+  if (NULL == gorc->contract_terms)
   {
-    GNUNET_break (0);
-    phase_end (gorc,
-               TALER_MHD_reply_with_error (
-                 gorc->sc.con,
-                 MHD_HTTP_INTERNAL_SERVER_ERROR,
-                 TALER_EC_MERCHANT_GENERIC_DB_CONTRACT_CONTENT_INVALID,
-                 hc->infix));
-    return;
+    gorc->contract_terms = TALER_MERCHANT_contract_parse (
+      gorc->contract_terms_json,
+      true);
+
+    if (NULL == gorc->contract_terms)
+    {
+      GNUNET_break (0);
+      phase_end (gorc,
+                 TALER_MHD_reply_with_error (
+                   gorc->sc.con,
+                   MHD_HTTP_INTERNAL_SERVER_ERROR,
+                   TALER_EC_MERCHANT_GENERIC_DB_CONTRACT_CONTENT_INVALID,
+                   hc->infix));
+      return;
+    }
   }
-  if (! gorc->order_only)
+
+  switch (gorc->contract_terms->version)
+  {
+  case TALER_MERCHANT_CONTRACT_VERSION_0:
+    gorc->contract_amount = gorc->contract_terms->details.v0.brutto;
+    break;
+  case TALER_MERCHANT_CONTRACT_VERSION_1:
+    if (gorc->choice_index >= 0)
+    {
+      if (gorc->choice_index >=
+          gorc->contract_terms->details.v1.choices_len)
+      {
+        GNUNET_break (0);
+        phase_end (gorc,
+                   TALER_MHD_reply_with_error (
+                     gorc->sc.con, MHD_HTTP_INTERNAL_SERVER_ERROR,
+                     TALER_EC_GENERIC_DB_INVARIANT_FAILURE,
+                     NULL));
+        return;
+      }
+
+      gorc->contract_amount =
+        gorc->contract_terms->details.v1.choices[gorc->choice_index].amount;
+    }
+    else
+    {
+      GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
+                  "choice index %i for order %s is invalid or not yet available",
+                  gorc->choice_index,
+                  gorc->contract_terms->order_id);
+    }
+    break;
+  default:
+    {
+      GNUNET_break (0);
+      phase_end (gorc,
+                 TALER_MHD_reply_with_error (
+                   gorc->sc.con,
+                   MHD_HTTP_INTERNAL_SERVER_ERROR,
+                   TALER_EC_MERCHANT_GET_ORDERS_ID_INVALID_CONTRACT_VERSION,
+                   NULL));
+      return;
+    }
+  }
+
+  if (! gorc->order_only && GNUNET_OK !=
+      TALER_JSON_contract_hash (gorc->contract_terms_json,
+                                &gorc->h_contract_terms))
   {
-    if (GNUNET_OK !=
-        TALER_JSON_contract_hash (gorc->contract_terms,
-                                  &gorc->h_contract_terms))
     {
       GNUNET_break (0);
       phase_end (gorc,
@@ -754,6 +790,7 @@ phase_parse_contract (struct GetOrderRequestContext *gorc)
       return;
     }
   }
+  GNUNET_assert (NULL != gorc->contract_terms_json);
   GNUNET_assert (NULL != gorc->contract_terms);
   gorc->phase++;
 }
@@ -819,7 +856,7 @@ phase_check_repurchase (struct GetOrderRequestContext *gorc)
   MHD_RESULT ret;
 
   if ( (gorc->paid) ||
-       (NULL == gorc->fulfillment_url) ||
+       (NULL == gorc->contract_terms->fulfillment_url) ||
        (NULL == gorc->session_id) )
   {
     /* Repurchase cannot apply */
@@ -829,10 +866,11 @@ phase_check_repurchase (struct GetOrderRequestContext *gorc)
   GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
               "Running re-purchase detection for %s/%s\n",
               gorc->session_id,
-              gorc->fulfillment_url);
+              gorc->contract_terms->fulfillment_url);
   qs = TMH_db->lookup_order_by_fulfillment (TMH_db->cls,
                                             hc->instance->settings.id,
-                                            gorc->fulfillment_url,
+                                            gorc->contract_terms->
+                                            fulfillment_url,
                                             gorc->session_id,
                                             TALER_EXCHANGE_YNA_NO !=
                                             gorc->allow_refunded_for_repurchase,
@@ -854,7 +892,7 @@ phase_check_repurchase (struct GetOrderRequestContext *gorc)
     GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
                 "No already paid order for %s/%s\n",
                 gorc->session_id,
-                gorc->fulfillment_url);
+                gorc->contract_terms->fulfillment_url);
     gorc->phase++;
     return;
   }
@@ -900,13 +938,16 @@ phase_check_repurchase (struct GetOrderRequestContext *gorc)
     GNUNET_JSON_pack_string ("already_paid_order_id",
                              already_paid_order_id),
     GNUNET_JSON_pack_string ("already_paid_fulfillment_url",
-                             gorc->fulfillment_url),
-    TALER_JSON_pack_amount ("total_amount",
-                            &gorc->contract_amount),
+                             gorc->contract_terms->fulfillment_url),
+    /* undefined for unpaid v1 contracts */
+    GNUNET_JSON_pack_allow_null (
+      TALER_JSON_pack_amount ("total_amount",
+                              &gorc->contract_amount)),
     GNUNET_JSON_pack_string ("summary",
-                             gorc->summary),
+                             gorc->contract_terms->summary),
     GNUNET_JSON_pack_timestamp ("creation_time",
-                                gorc->timestamp));
+                                gorc->contract_terms->timestamp));
+  GNUNET_free (order_status_url);
   GNUNET_free (taler_pay_uri);
   GNUNET_free (already_paid_order_id);
   phase_end (gorc,
@@ -947,6 +988,12 @@ phase_unpaid_finish (struct GetOrderRequestContext *gorc)
     MHD_suspend_connection (gorc->sc.con);
     return;
   }
+  order_status_url = TMH_make_order_status_url (gorc->sc.con,
+                                                hc->infix,
+                                                gorc->session_id,
+                                                hc->instance->settings.id,
+                                                &gorc->claim_token,
+                                                NULL);
   if (! gorc->order_only)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
@@ -956,10 +1003,13 @@ phase_unpaid_finish (struct GetOrderRequestContext *gorc)
                TALER_MHD_REPLY_JSON_PACK (
                  gorc->sc.con,
                  MHD_HTTP_OK,
+                 GNUNET_JSON_pack_string ("order_status_url",
+                                          order_status_url),
                  GNUNET_JSON_pack_object_incref ("contract_terms",
-                                                 gorc->contract_terms),
+                                                 gorc->contract_terms_json),
                  GNUNET_JSON_pack_string ("order_status",
                                           "claimed")));
+    GNUNET_free (order_status_url);
     return;
   }
   taler_pay_uri = TMH_make_taler_pay_uri (gorc->sc.con,
@@ -967,12 +1017,6 @@ phase_unpaid_finish (struct GetOrderRequestContext *gorc)
                                           gorc->session_id,
                                           hc->instance->settings.id,
                                           &gorc->claim_token);
-  order_status_url = TMH_make_order_status_url (gorc->sc.con,
-                                                hc->infix,
-                                                gorc->session_id,
-                                                hc->instance->settings.id,
-                                                &gorc->claim_token,
-                                                NULL);
   ret = TALER_MHD_REPLY_JSON_PACK (
     gorc->sc.con,
     MHD_HTTP_OK,
@@ -982,12 +1026,14 @@ phase_unpaid_finish (struct GetOrderRequestContext *gorc)
                              order_status_url),
     GNUNET_JSON_pack_string ("order_status",
                              "unpaid"),
-    TALER_JSON_pack_amount ("total_amount",
-                            &gorc->contract_amount),
+    /* undefined for unpaid v1 contracts */
+    GNUNET_JSON_pack_allow_null (
+      TALER_JSON_pack_amount ("total_amount",
+                              &gorc->contract_amount)),
     GNUNET_JSON_pack_string ("summary",
-                             gorc->summary),
+                             gorc->contract_terms->summary),
     GNUNET_JSON_pack_timestamp ("creation_time",
-                                gorc->timestamp));
+                                gorc->contract_terms->timestamp));
   GNUNET_free (taler_pay_uri);
   GNUNET_free (order_status_url);
   phase_end (gorc,
@@ -1048,25 +1094,27 @@ process_refunds_cb (
        NULL != tq;
        tq = tq->next)
   {
-    if (0 ==
+    if (0 !=
+        strcmp (exchange_url,
+                tq->exchange_url))
+      continue;
+    if (0 !=
         GNUNET_memcmp (&tq->coin_pub,
                        coin_pub))
+      continue;
+    if (GNUNET_OK !=
+        TALER_amount_cmp_currency (
+          &gorc->deposit_fees_total,
+          &tq->deposit_fee))
     {
-      if (GNUNET_OK !=
-          TALER_amount_cmp_currency (
-            &gorc->deposit_fees_total,
-            &tq->deposit_fee))
-      {
-        gorc->refund_currency_mismatch = true;
-        return;
-      }
-
-      GNUNET_assert (
-        0 <=
-        TALER_amount_subtract (&gorc->deposit_fees_total,
-                               &gorc->deposit_fees_total,
-                               &tq->deposit_fee));
+      gorc->refund_currency_mismatch = true;
+      return;
     }
+    GNUNET_assert (
+      0 <=
+      TALER_amount_subtract (&gorc->deposit_fees_total,
+                             &gorc->deposit_fees_total,
+                             &tq->deposit_fee));
   }
   if (GNUNET_OK !=
       TALER_amount_cmp_currency (
@@ -1098,10 +1146,12 @@ phase_check_refunds (struct GetOrderRequestContext *gorc)
 
   GNUNET_assert (! gorc->order_only);
   GNUNET_assert (gorc->paid);
+
   /* Accumulate refunds, if any. */
   GNUNET_assert (GNUNET_OK ==
                  TALER_amount_set_zero (gorc->contract_amount.currency,
                                         &gorc->refund_amount));
+
   qs = TMH_db->lookup_refunds_detailed (
     TMH_db->cls,
     hc->instance->settings.id,
@@ -1197,6 +1247,13 @@ deposit_cb (
 static void
 phase_check_deposits (struct GetOrderRequestContext *gorc)
 {
+  GNUNET_assert (! gorc->order_only);
+  GNUNET_assert (gorc->paid);
+
+  /* amount must be always valid for paid orders */
+  GNUNET_assert (GNUNET_OK ==
+                 TALER_amount_is_valid (&gorc->contract_amount));
+
   GNUNET_assert (GNUNET_OK ==
                  TALER_amount_set_zero (gorc->contract_amount.currency,
                                         &gorc->deposits_total));
@@ -1290,12 +1347,16 @@ phase_check_local_transfers (struct GetOrderRequestContext *gorc)
   struct TMH_HandlerContext *hc = gorc->hc;
   enum GNUNET_DB_QueryStatus qs;
 
+  GNUNET_assert (gorc->paid);
+  GNUNET_assert (! gorc->order_only);
+
   GNUNET_assert (GNUNET_OK ==
                  TALER_amount_set_zero (gorc->contract_amount.currency,
                                         &gorc->deposits_total));
   GNUNET_assert (GNUNET_OK ==
                  TALER_amount_set_zero (gorc->contract_amount.currency,
                                         &gorc->deposit_fees_total));
+
   qs = TMH_db->lookup_transfer_details_by_order (TMH_db->cls,
                                                  gorc->order_serial,
                                                  &process_transfer_details,
@@ -1367,7 +1428,7 @@ phase_check_local_transfers (struct GetOrderRequestContext *gorc)
       TMH_notify_order_change (hc->instance,
                                TMH_OSF_PAID
                                | TMH_OSF_WIRED,
-                               gorc->timestamp,
+                               gorc->contract_terms->timestamp,
                                gorc->order_serial);
     }
   }
@@ -1386,7 +1447,9 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
   struct TMH_HandlerContext *hc = gorc->hc;
   MHD_RESULT ret;
   char *order_status_url;
-  json_t *choice_index;
+
+  GNUNET_assert (gorc->paid);
+  GNUNET_assert (! gorc->order_only);
 
   {
     struct TALER_PrivateContractHashP *h_contract = NULL;
@@ -1412,18 +1475,7 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
   {
     GNUNET_break (GNUNET_YES ==
                   TALER_amount_is_zero (&gorc->contract_amount));
-    gorc->last_payment = gorc->timestamp;
-  }
-  if (-1 != gorc->choice_index)
-  {
-    GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
-                "Choice index is %d\n",
-                gorc->choice_index);
-    choice_index = json_integer ((json_int_t) gorc->choice_index);
-  }
-  else
-  {
-    choice_index = NULL;
+    gorc->last_payment = gorc->contract_terms->timestamp;
   }
   ret = TALER_MHD_REPLY_JSON_PACK (
     gorc->sc.con,
@@ -1444,7 +1496,7 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
     TALER_JSON_pack_amount ("deposit_total",
                             &gorc->deposits_total),
     GNUNET_JSON_pack_object_incref ("contract_terms",
-                                    gorc->contract_terms),
+                                    gorc->contract_terms_json),
     GNUNET_JSON_pack_string ("order_status",
                              "paid"),
     GNUNET_JSON_pack_timestamp ("last_payment",
@@ -1455,18 +1507,19 @@ phase_reply_result (struct GetOrderRequestContext *gorc)
                            gorc->wired),
     GNUNET_JSON_pack_bool ("refund_pending",
                            gorc->refund_pending),
-    TALER_JSON_pack_amount ("refund_amount",
-                            &gorc->refund_amount),
+    GNUNET_JSON_pack_allow_null (
+      TALER_JSON_pack_amount ("refund_amount",
+                              &gorc->refund_amount)),
     GNUNET_JSON_pack_array_steal ("wire_details",
                                   gorc->wire_details),
     GNUNET_JSON_pack_array_steal ("refund_details",
                                   gorc->refund_details),
     GNUNET_JSON_pack_string ("order_status_url",
                              order_status_url),
-    GNUNET_JSON_pack_allow_null (
-      GNUNET_JSON_pack_object_steal (
-        "choice_index",
-        choice_index)));
+    (gorc->choice_index >= 0)
+      ? GNUNET_JSON_pack_int64 ("choice_index",
+                                gorc->choice_index)
+      : GNUNET_JSON_pack_end_ ());
   GNUNET_free (order_status_url);
   gorc->wire_details = NULL;
   gorc->refund_details = NULL;
@@ -1516,10 +1569,10 @@ TMH_private_get_orders_ID (
     gorc->session_id = MHD_lookup_connection_value (connection,
                                                     MHD_GET_ARGUMENT_KIND,
                                                     "session_id");
-    if (! (TALER_arg_to_yna (connection,
-                             "allow_refunded_for_repurchase",
-                             TALER_EXCHANGE_YNA_NO,
-                             &gorc->allow_refunded_for_repurchase)) )
+    if (! (TALER_MHD_arg_to_yna (connection,
+                                 "allow_refunded_for_repurchase",
+                                 TALER_EXCHANGE_YNA_NO,
+                                 &gorc->allow_refunded_for_repurchase)) )
       return TALER_MHD_reply_with_error (connection,
                                          MHD_HTTP_BAD_REQUEST,
                                          TALER_EC_GENERIC_PARAMETER_MALFORMED,
