@@ -43,7 +43,7 @@
 static void
 free_wm (struct TMH_WireMethod *wm)
 {
-  GNUNET_free (wm->payto_uri);
+  GNUNET_free (wm->payto_uri.full_payto);
   GNUNET_free (wm->wire_method);
   GNUNET_free (wm);
 }
