@@ -189,7 +189,7 @@ TMH_private_patch_products_ID (
   }
 
   if (NULL == pd.image)
-    pd.image = "";
+    pd.image = (char *) "";
   if (! TMH_image_data_url_valid (pd.image))
   {
     GNUNET_break_op (0);
@@ -261,16 +261,16 @@ TMH_private_patch_products_ID (
   }
   if (-1 != no_cat)
   {
-    char cats[24];
+    char cat_str[24];
 
-    GNUNET_snprintf (cats,
-                     sizeof (cats),
+    GNUNET_snprintf (cat_str,
+                     sizeof (cat_str),
                      "%llu",
                      (unsigned long long) no_cat);
     ret = TALER_MHD_reply_with_error (connection,
                                       MHD_HTTP_NOT_FOUND,
                                       TALER_EC_MERCHANT_GENERIC_CATEGORY_UNKNOWN,
-                                      cats);
+                                      cat_str);
     goto cleanup;
   }
   if (no_product)
