@@ -365,7 +365,7 @@ retry:
     TMH_reload_instances (mi->settings.id);
   }
   if (0 == strcmp (is.id,
-                   "default"))
+                   "admin"))
   {
     GNUNET_free (TMH_default_auth); /* clear it if the default instance was
                                        created */
