@@ -46,6 +46,10 @@ static bool
 token_families_equal (const struct TALER_MERCHANTDB_TokenFamilyDetails *tf1,
                       const struct TALER_MERCHANTDB_TokenFamilyDetails *tf2)
 {
+  /* Note: we're not comparing 'cipher', as that is selected
+     in the database to some default value and we currently
+     do not allow the SPA to change it. As a result, it should
+     always be "NULL" in tf1 and the DB-default in tf2. */
   return ( (0 == strcmp (tf1->slug,
                          tf2->slug)) &&
            (0 == strcmp (tf1->name,
