@@ -19,6 +19,7 @@
  * @author Christian Grothoff
  */
 #include "platform.h"
+#include "microhttpd.h"
 #include <gnunet/gnunet_util_lib.h>
 #include <jansson.h>
 #include <pthread.h>
@@ -42,20 +43,36 @@
 /**
  * How long do we wait between requests if all we wait
  * for is a change in the AML investigation status?
+ * Default value.
  */
 #define AML_FREQ GNUNET_TIME_relative_multiply ( \
           GNUNET_TIME_UNIT_HOURS, \
           6)
 
+/**
+ * How long do we wait between requests if all we wait
+ * for is a change in the AML investigation status?
+ */
+static struct GNUNET_TIME_Relative aml_freq;
+
 /**
  * How frequently do we check for updates to our KYC status
  * if there is no actual reason to check? Set to a very low
  * frequency, just to ensure we eventually notice.
+ * Default value.
  */
 #define AML_LOW_FREQ GNUNET_TIME_relative_multiply ( \
           GNUNET_TIME_UNIT_DAYS, \
           7)
 
+/**
+ * How frequently do we check for updates to our KYC status
+ * if there is no actual reason to check? Set to a very low
+ * frequency, just to ensure we eventually notice.
+ */
+static struct GNUNET_TIME_Relative aml_low_freq;
+
+
 /**
  * How many inquiries do we process concurrently at most.
  */
@@ -141,6 +158,7 @@ struct Account
    * was last active.
    */
   uint64_t account_gen;
+
 };
 
 
@@ -210,6 +228,12 @@ struct Inquiry
    */
   struct GNUNET_TIME_Relative backoff;
 
+  /**
+   * Rule generation known to the client, 0 for none.
+   * Corresponds to the decision row in the exchange.
+   */
+  uint64_t rule_gen;
+
   /**
    * Last HTTP status returned by the exchange from
    * the /kyc-check endpoint.
@@ -227,6 +251,13 @@ struct Inquiry
    */
   bool not_first_time;
 
+  /**
+   * Do soft limits on transactions apply to this merchant for operations
+   * merchants care about? If so, we should increase our request frequency
+   * and ask more often to see if they were lifted.
+   */
+  bool zero_limited;
+
   /**
    * Did we not run this inquiry due to limits?
    */
@@ -446,6 +477,7 @@ store_kyc_status (
   json_decref (i->jlimits);
   jlimits = json_array ();
   GNUNET_assert (NULL != jlimits);
+  i->zero_limited = false;
   for (unsigned int j = 0; j<account_kyc_status->limits_length; j++)
   {
     const struct TALER_EXCHANGE_AccountLimit *limit
@@ -453,6 +485,14 @@ store_kyc_status (
 
     pack_limit (limit,
                 jlimits);
+    if (TALER_amount_is_zero (&limit->threshold) &&
+        limit->soft_limit &&
+        ( (TALER_KYCLOGIC_KYC_TRIGGER_DEPOSIT == limit->operation_type) ||
+          (TALER_KYCLOGIC_KYC_TRIGGER_AGGREGATE == limit->operation_type) ||
+          (TALER_KYCLOGIC_KYC_TRIGGER_TRANSACTION == limit->operation_type) ) )
+    {
+      i->zero_limited = true;
+    }
   }
   i->jlimits = jlimits;
   GNUNET_break (! GNUNET_is_zero (&account_kyc_status->access_token));
@@ -482,6 +522,7 @@ exchange_check_cb (
   i->kyc = NULL;
   i->last_http_status = ks->hr.http_status;
   i->last_ec = ks->hr.ec;
+  i->rule_gen = 0;
   GNUNET_log (GNUNET_ERROR_TYPE_INFO,
               "Checking KYC status of `%s' at `%s' is %u\n",
               i->a->merchant_account_uri.full_payto,
@@ -492,24 +533,26 @@ exchange_check_cb (
   case MHD_HTTP_OK:
     if (! i->kyc_ok)
       progress = true;
+    i->rule_gen = ks->details.ok.rule_gen;
     i->last_kyc_check = GNUNET_TIME_timestamp_get ();
     /* exchange says KYC is OK, gives status information */
     store_kyc_status (i,
                       &ks->details.ok);
     i->backoff = GNUNET_TIME_UNIT_ZERO;
-    if (i->aml_review)
+    if (i->aml_review || i->zero_limited)
     {
       if (! progress)
-        i->due = GNUNET_TIME_relative_to_absolute (AML_FREQ);
+        i->due = GNUNET_TIME_relative_to_absolute (aml_freq);
     }
     else
     {
       /* KYC is OK, only check again if triggered */
-      i->due = GNUNET_TIME_relative_to_absolute (AML_LOW_FREQ);
+      i->due = GNUNET_TIME_relative_to_absolute (aml_low_freq);
     }
     break;
   case MHD_HTTP_ACCEPTED:
     progress = ! i->auth_ok;
+    i->rule_gen = ks->details.ok.rule_gen;
     i->last_kyc_check = GNUNET_TIME_timestamp_get ();
 
     /* exchange says KYC is required */
@@ -531,7 +574,7 @@ exchange_check_cb (
     json_decref (i->jlimits);
     i->jlimits = NULL;
     /* KYC is OK, only check again if triggered */
-    i->due = GNUNET_TIME_relative_to_absolute (AML_LOW_FREQ);
+    i->due = GNUNET_TIME_relative_to_absolute (aml_low_freq);
     break;
   case MHD_HTTP_FORBIDDEN: /* bad signature */
     i->last_kyc_check = GNUNET_TIME_timestamp_get ();
@@ -547,8 +590,8 @@ exchange_check_cb (
     i->last_kyc_check = GNUNET_TIME_timestamp_get ();
     /* Account unknown => no KYC auth yet */
     i->auth_ok = false;
-    /* unknown account => no requirements! */
-    i->kyc_ok = true;
+    /* unknown account => wire transfer required! */
+    i->kyc_ok = false;
     /* There should not be any limits yet, but clear them
        just in case the exchange has amnesia */
     json_decref (i->jlimits);
@@ -579,6 +622,7 @@ exchange_check_cb (
                                         EXCHANGE_TIMEOUT);
     i->last_kyc_check = GNUNET_TIME_timestamp_get ();
     i->due = GNUNET_TIME_relative_to_absolute (i->backoff);
+    i->auth_ok = false;
     break;
   }
 
@@ -593,6 +637,7 @@ exchange_check_cb (
       i->last_kyc_check,
       i->last_http_status,
       i->last_ec,
+      i->rule_gen,
       (i->auth_ok)
       ? &i->access_token
       : NULL,
@@ -637,6 +682,13 @@ inquiry_work (void *cls)
   i->task = NULL;
   if (! GNUNET_TIME_absolute_is_past (i->due))
   {
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Will start inquiry on %s for %s in %s\n",
+                i->a->merchant_account_uri.full_payto,
+                i->e->keys->exchange_url,
+                GNUNET_TIME_relative2s (
+                  GNUNET_TIME_absolute_get_remaining (i->due),
+                  true));
     i->task
       = GNUNET_SCHEDULER_add_at (i->due,
                                  &inquiry_work,
@@ -674,8 +726,9 @@ inquiry_work (void *cls)
     i->e->keys->exchange_url,
     &i->a->h_payto,
     &i->a->ap,
+    i->rule_gen,
     lpt,
-    i->not_first_time
+    i->not_first_time && (! test_mode)
     ? EXCHANGE_TIMEOUT
     : GNUNET_TIME_UNIT_ZERO,
     &exchange_check_cb,
@@ -754,6 +807,7 @@ start_inquiry (struct Exchange *e,
                                   &i->kyc_ok,
                                   &i->last_http_status,
                                   &i->last_ec,
+                                  &i->rule_gen,
                                   &i->last_kyc_check,
                                   &i->aml_review,
                                   &i->jlimits);
@@ -773,15 +827,27 @@ start_inquiry (struct Exchange *e,
        so let's check, but slowly within the next minute
        so that we do not overdo it if this process happens
        to be restarted a lot. */
-    i->due = GNUNET_TIME_relative_to_absolute (
-      GNUNET_TIME_randomize (GNUNET_TIME_UNIT_MINUTES));
+    if (GNUNET_YES != test_mode)
+    {
+      i->due = GNUNET_TIME_relative_to_absolute (
+        GNUNET_TIME_randomize (GNUNET_TIME_UNIT_MINUTES));
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Previous KYC status is OK, randomizing inquiry to start at %s\n",
+                  GNUNET_TIME_absolute2s (i->due));
+    }
     break;
   case MHD_HTTP_ACCEPTED:
     /* KYC required, due immediately */
     break;
   case MHD_HTTP_NO_CONTENT:
     /* KYC is OFF, only check again if triggered */
-    i->due = GNUNET_TIME_relative_to_absolute (AML_LOW_FREQ);
+    if (GNUNET_YES != test_mode)
+    {
+      i->due = GNUNET_TIME_relative_to_absolute (aml_low_freq);
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "KYC was disabled, randomizing inquiry to start at %s\n",
+                  GNUNET_TIME_absolute2s (i->due));
+    }
     break;
   case MHD_HTTP_FORBIDDEN: /* bad signature */
   case MHD_HTTP_NOT_FOUND: /* account unknown */
@@ -790,8 +856,15 @@ start_inquiry (struct Exchange *e,
     break;
   default:
     /* start with decent back-off after hard failure */
-    i->backoff
-      = GNUNET_TIME_randomize (GNUNET_TIME_UNIT_MINUTES);
+    if (GNUNET_YES != test_mode)
+    {
+      i->backoff
+        = GNUNET_TIME_randomize (GNUNET_TIME_UNIT_MINUTES);
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Last KYC check failed, starting with backoff %s\n",
+                  GNUNET_TIME_relative2s (i->backoff,
+                                          true));
+    }
     break;
   }
   inquiry_work (i);
@@ -866,10 +939,17 @@ start_inquiries (struct Account *a)
   for (struct Exchange *e = e_head;
        NULL != e;
        e = e->next)
+  {
     if (is_eligible (e->keys,
                      a))
       start_inquiry (e,
                      a);
+    else
+      GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                  "Account %s not eligible at exchange %s\n",
+                  a->merchant_account_uri.full_payto,
+                  e->keys->exchange_url);
+  }
 }
 
 
@@ -933,7 +1013,11 @@ account_cb (
       = *merchant_priv;
     TALER_full_payto_normalize_and_hash (a->merchant_account_uri,
                                          &a->h_payto);
-
+    GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+                "Found account %s of instance %s with H_PAYTO %s\n",
+                ad->payto_uri.full_payto,
+                ad->instance_id,
+                GNUNET_sh2s (&a->h_payto.hash));
     GNUNET_CONTAINER_DLL_insert (a_head,
                                  a_tail,
                                  a);
@@ -1009,9 +1093,11 @@ find_keys (const char *exchange_url)
   enum GNUNET_DB_QueryStatus qs;
   struct TALER_EXCHANGE_Keys *keys;
   struct Exchange *e;
+  struct GNUNET_TIME_Absolute first_retry;
 
   qs = db_plugin->select_exchange_keys (db_plugin->cls,
                                         exchange_url,
+                                        &first_retry,
                                         &keys);
   if (qs < 0)
   {
@@ -1283,6 +1369,7 @@ shutdown_task (void *cls)
                                  a_tail,
                                  a);
     GNUNET_free (a->merchant_account_uri.full_payto);
+    GNUNET_free (a->instance_id);
     GNUNET_free (a);
   }
   if (NULL != eh_accounts)
@@ -1339,6 +1426,30 @@ run (void *cls,
   (void) cfgfile;
 
   cfg = c;
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_time (cfg,
+                                           "merchant-kyccheck",
+                                           "AML_FREQ",
+                                           &aml_freq))
+  {
+    GNUNET_log_config_missing (GNUNET_ERROR_TYPE_WARNING,
+                               "merchant-kyccheck",
+                               "AML_FREQ");
+    /* use default */
+    aml_freq = AML_FREQ;
+  }
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_time (cfg,
+                                           "merchant-kyccheck",
+                                           "AML_LOW_FREQ",
+                                           &aml_freq))
+  {
+    GNUNET_log_config_missing (GNUNET_ERROR_TYPE_WARNING,
+                               "merchant-kyccheck",
+                               "AML_LOW_FREQ");
+    /* use default */
+    aml_low_freq = AML_LOW_FREQ;
+  }
   GNUNET_SCHEDULER_add_shutdown (&shutdown_task,
                                  NULL);
   ctx = GNUNET_CURL_init (&GNUNET_CURL_gnunet_scheduler_reschedule,
