@@ -30,10 +30,13 @@ TALER_MERCHANTDB_product_details_free (
 {
   GNUNET_free (pd->description);
   json_decref (pd->description_i18n);
+  pd->description_i18n = NULL;
   GNUNET_free (pd->unit);
   json_decref (pd->taxes);
+  pd->taxes = NULL;
   GNUNET_free (pd->image);
   json_decref (pd->address);
+  pd->address = NULL;
 }
 
 
@@ -44,7 +47,9 @@ TALER_MERCHANTDB_template_details_free (
   GNUNET_free (tp->template_description);
   GNUNET_free (tp->otp_id);
   json_decref (tp->editable_defaults);
+  tp->editable_defaults = NULL;
   json_decref (tp->template_contract);
+  tp->template_contract = NULL;
 }
 
 
@@ -79,6 +84,10 @@ TALER_MERCHANTDB_token_family_details_free (
   GNUNET_free (tf->name);
   GNUNET_free (tf->description);
   json_decref (tf->description_i18n);
+  tf->description_i18n = NULL;
+  json_decref (tf->extra_data);
+  tf->extra_data = NULL;
+  GNUNET_free (tf->cipher_spec);
 }
 
 
@@ -88,6 +97,7 @@ TALER_MERCHANTDB_category_details_free (
 {
   GNUNET_free (cd->category_name);
   json_decref (cd->category_name_i18n);
+  cd->category_name_i18n = NULL;
 }
 
 
