@@ -40,16 +40,6 @@ struct KycStatusContext
    */
   void *kyc_cb_cls;
 
-  /**
-   * Filter, NULL to not filter.
-   */
-  const struct TALER_MerchantWireHashP *h_wire;
-
-  /**
-   * Filter, NULL to not filter.
-   */
-  const char *exchange_url;
-
   /**
    * Number of results found.
    */
@@ -77,29 +67,51 @@ kyc_status_cb (void *cls,
 {
   struct KycStatusContext *ksc = cls;
 
+  GNUNET_log (GNUNET_ERROR_TYPE_INFO,
+              "Got %u KYC records\n",
+              num_results);
   for (unsigned int i = 0; i < num_results; i++)
   {
     struct TALER_MerchantWireHashP h_wire;
-    uint64_t kyc_serial;
     char *exchange_url;
-    char *payto_uri;
+    struct TALER_FullPayto payto_uri;
     struct GNUNET_TIME_Timestamp last_check;
     bool kyc_ok;
+    struct TALER_AccountAccessTokenP access_token;
+    bool no_auth;
+    uint32_t h32;
+    uint32_t e32;
+    bool in_aml_review;
+    json_t *jlimits = NULL;
     struct GNUNET_PQ_ResultSpec rs[] = {
       GNUNET_PQ_result_spec_auto_from_type ("h_wire",
                                             &h_wire),
-      GNUNET_PQ_result_spec_uint64 ("exchange_kyc_serial",
-                                    &kyc_serial),
       GNUNET_PQ_result_spec_string ("payto_uri",
-                                    &payto_uri),
+                                    &payto_uri.full_payto),
       GNUNET_PQ_result_spec_string ("exchange_url",
                                     &exchange_url),
       GNUNET_PQ_result_spec_timestamp ("kyc_timestamp",
                                        &last_check),
       GNUNET_PQ_result_spec_bool ("kyc_ok",
                                   &kyc_ok),
+      GNUNET_PQ_result_spec_allow_null (
+        GNUNET_PQ_result_spec_auto_from_type ("access_token",
+                                              &access_token),
+        &no_auth),
+      GNUNET_PQ_result_spec_uint32 ("exchange_http_status",
+                                    &h32),
+      GNUNET_PQ_result_spec_uint32 ("exchange_ec_code",
+                                    &e32),
+      GNUNET_PQ_result_spec_bool ("aml_review",
+                                  &in_aml_review),
+      GNUNET_PQ_result_spec_allow_null (
+        TALER_PQ_result_spec_json ("jaccount_limits",
+                                   &jlimits),
+        NULL),
       GNUNET_PQ_result_spec_end
     };
+    unsigned int last_http_status;
+    enum TALER_ErrorCode last_ec;
 
     if (GNUNET_OK !=
         GNUNET_PQ_extract_result (result,
@@ -110,28 +122,22 @@ kyc_status_cb (void *cls,
       ksc->failure = true;
       return;
     }
-    if ( (NULL != ksc->exchange_url) &&
-         (0 != strcmp (ksc->exchange_url,
-                       exchange_url)) )
-    {
-      GNUNET_PQ_cleanup_result (rs);
-      continue;
-    }
-    if ( (NULL != ksc->h_wire) &&
-         (0 != GNUNET_memcmp (ksc->h_wire,
-                              &h_wire)) )
-    {
-      GNUNET_PQ_cleanup_result (rs);
-      continue;
-    }
+    last_http_status = (unsigned int) h32;
+    last_ec = (enum TALER_ErrorCode) (int) e32;
     ksc->count++;
     ksc->kyc_cb (ksc->kyc_cb_cls,
                  &h_wire,
-                 kyc_serial,
                  payto_uri,
                  exchange_url,
                  last_check,
-                 kyc_ok);
+                 kyc_ok,
+                 (no_auth)
+                 ? NULL
+                 : &access_token,
+                 last_http_status,
+                 last_ec,
+                 in_aml_review,
+                 jlimits);
     GNUNET_PQ_cleanup_result (rs);
   }
 }
@@ -149,12 +155,16 @@ TMH_PG_account_kyc_get_status (
   struct PostgresClosure *pg = cls;
   struct KycStatusContext ksc = {
     .kyc_cb = kyc_cb,
-    .kyc_cb_cls = kyc_cb_cls,
-    .exchange_url = exchange_url,
-    .h_wire = h_wire
+    .kyc_cb_cls = kyc_cb_cls
   };
   struct GNUNET_PQ_QueryParam params[] = {
     GNUNET_PQ_query_param_string (merchant_id),
+    NULL == exchange_url
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_string (exchange_url),
+    NULL == h_wire
+    ? GNUNET_PQ_query_param_null ()
+    : GNUNET_PQ_query_param_auto_from_type (h_wire),
     GNUNET_PQ_query_param_end
   };
   enum GNUNET_DB_QueryStatus qs;
@@ -163,23 +173,33 @@ TMH_PG_account_kyc_get_status (
   PREPARE (pg,
            "lookup_kyc_status",
            "SELECT"
-           " h_wire"
-           ",exchange_kyc_serial"
-           ",payto_uri"
-           ",exchange_url"
-           ",kyc_timestamp"
-           ",kyc_ok"
-           " FROM merchant_instances"
-           " JOIN merchant_accounts"
+           " ma.h_wire"
+           ",ma.payto_uri"
+           ",mk.exchange_url"
+           ",mk.kyc_timestamp"
+           ",mk.kyc_ok"
+           ",mk.access_token"
+           ",mk.exchange_http_status"
+           ",mk.exchange_ec_code"
+           ",mk.aml_review"
+           ",mk.jaccount_limits"
+           " FROM merchant_instances mi"
+           " JOIN merchant_accounts ma"
            "   USING (merchant_serial)"
-           " JOIN merchant_kyc"
+           " JOIN merchant_kyc mk"
            "   USING (account_serial)"
-           " WHERE merchant_instances.merchant_id=$1");
-  qs = GNUNET_PQ_eval_prepared_multi_select (pg->conn,
-                                             "lookup_kyc_status",
-                                             params,
-                                             &kyc_status_cb,
-                                             &ksc);
+           " WHERE (mi.merchant_id=$1)"
+           "   AND ma.active"
+           "   AND ( ($2::TEXT IS NULL)"
+           "      OR (mk.exchange_url=$2) )"
+           "   AND ( ($3::BYTEA IS NULL)"
+           "      OR (ma.h_wire=$3) );");
+  qs = GNUNET_PQ_eval_prepared_multi_select (
+    pg->conn,
+    "lookup_kyc_status",
+    params,
+    &kyc_status_cb,
+    &ksc);
   if (ksc.failure)
   {
     GNUNET_break (0);
