@@ -30,7 +30,8 @@ enum GNUNET_DB_QueryStatus
 TMH_PG_insert_deposit_to_transfer (
   void *cls,
   uint64_t deposit_serial,
-  const struct TALER_EXCHANGE_DepositData *dd)
+  const struct TALER_EXCHANGE_DepositData *dd,
+  bool *wpc)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -43,12 +44,11 @@ TMH_PG_insert_deposit_to_transfer (
     GNUNET_PQ_query_param_auto_from_type (&dd->wtid),
     GNUNET_PQ_query_param_end
   };
-  bool wpc;
   bool conflict;
   bool no_exchange_pub;
   struct GNUNET_PQ_ResultSpec rs[] = {
     GNUNET_PQ_result_spec_bool ("out_wire_pending_cleared",
-                                &wpc),
+                                wpc),
     GNUNET_PQ_result_spec_bool ("out_conflict",
                                 &conflict),
     GNUNET_PQ_result_spec_bool ("out_no_exchange_pub",
@@ -57,6 +57,7 @@ TMH_PG_insert_deposit_to_transfer (
   };
   enum GNUNET_DB_QueryStatus qs;
 
+  *wpc = false;
   PREPARE (pg,
            "insert_deposit_to_transfer",
            "SELECT"
@@ -74,7 +75,7 @@ TMH_PG_insert_deposit_to_transfer (
   if (no_exchange_pub)
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
                 "Exchange public key unknown (bug!?)\n");
-  if (wpc)
+  if (*wpc)
     GNUNET_log (GNUNET_ERROR_TYPE_INFO,
                 "Wire pending flag cleared (good!)\n");
   if (conflict)
