@@ -33,7 +33,7 @@ TMH_PG_insert_spent_token (
   const struct TALER_TokenIssuePublicKeyHashP *h_issue_pub,
   const struct TALER_TokenUsePublicKeyP *use_pub,
   const struct TALER_TokenUseSignatureP *use_sig,
-  const struct TALER_TokenIssueSignatureP *issue_sig)
+  const struct TALER_TokenIssueSignature *issue_sig)
 {
   struct PostgresClosure *pg = cls;
   struct GNUNET_PQ_QueryParam params[] = {
@@ -49,7 +49,7 @@ TMH_PG_insert_spent_token (
   PREPARE (pg,
            "spent_token_insert",
            "INSERT INTO merchant_used_tokens"
-           "(merchant_serial" /* TODO: Remove merchant_serial field from the db, it's already given by token_family.merchant_serial. */
+           "(merchant_serial" /* FIXME-#9434: Remove merchant_serial field from the db, it's already given by token_family.merchant_serial. */
            ",token_family_key_serial"
            ",h_contract_terms"
            ",token_pub"
@@ -61,7 +61,7 @@ TMH_PG_insert_spent_token (
            "   USING (token_family_serial)"
            " WHERE h_pub = $1");
 
-  /* TODO: Increase used counter on merchant_token_family table. */
+  /* FIXME-#9434: Increase used counter on merchant_token_family table. */
   return GNUNET_PQ_eval_prepared_non_select (pg->conn,
                                              "spent_token_insert",
                                              params);
