@@ -41,6 +41,8 @@ DECLARE
   my_signkey_serial INT8;
   my_credit_serial INT8;
   my_affected_orders RECORD;
+  my_merchant_serial INT8;
+  my_order_id TEXT;
   i INT8;
   curs CURSOR (arg_coin_pub BYTEA) FOR
     SELECT mcon.deposit_confirmation_serial,
@@ -220,6 +222,29 @@ LOOP
             FROM merchant_deposit_confirmations mdc
              WHERE mdc.wire_pending
                AND mdc.order_serial=my_affected_orders.order_serial);
+
+      -- Select merchant_serial and order_id for webhook
+      SELECT merchant_serial, order_id
+        INTO my_merchant_serial, my_order_id
+        FROM merchant_contract_terms
+       WHERE order_serial=my_affected_orders.order_serial;
+
+      -- Insert pending webhook if it exists
+      INSERT INTO merchant_pending_webhooks
+      (merchant_serial
+      ,webhook_serial
+      ,url
+      ,http_method
+      ,body)
+      SELECT mw.merchant_serial
+            ,mw.webhook_serial
+            ,mw.url
+            ,mw.http_method
+            ,replace_placeholder(mw.body_template, 'order_id', my_order_id)::TEXT
+      FROM merchant_webhook mw
+      WHERE mw.event_type = 'order_settled'
+        AND mw.merchant_serial = my_merchant_serial;
+
     END IF;
 
   END LOOP; -- END curs LOOP
