@@ -25,6 +25,7 @@
 #include "pg_lookup_product.h"
 #include "pg_helper.h"
 
+
 enum GNUNET_DB_QueryStatus
 TMH_PG_lookup_product (void *cls,
                        const char *instance_id,
@@ -83,17 +84,24 @@ TMH_PG_lookup_product (void *cls,
   }
   else
   {
+    char *my_description = NULL;
+    json_t *my_description_i18n = NULL;
+    char *my_unit = NULL;
+    char *my_image = NULL;
+    json_t *my_address = NULL;
+    json_t *my_taxes = NULL;
+    uint64_t *my_categories = NULL;
     struct GNUNET_PQ_ResultSpec rs[] = {
       GNUNET_PQ_result_spec_string ("description",
-                                    &pd->description),
+                                    &my_description),
       TALER_PQ_result_spec_json ("description_i18n",
-                                 &pd->description_i18n),
+                                 &my_description_i18n),
       GNUNET_PQ_result_spec_string ("unit",
-                                    &pd->unit),
+                                    &my_unit),
       TALER_PQ_result_spec_amount_with_currency ("price",
                                                  &pd->price),
       TALER_PQ_result_spec_json ("taxes",
-                                 &pd->taxes),
+                                 &my_taxes),
       GNUNET_PQ_result_spec_uint64 ("total_stock",
                                     &pd->total_stock),
       GNUNET_PQ_result_spec_uint64 ("total_sold",
@@ -101,9 +109,9 @@ TMH_PG_lookup_product (void *cls,
       GNUNET_PQ_result_spec_uint64 ("total_lost",
                                     &pd->total_lost),
       GNUNET_PQ_result_spec_string ("image",
-                                    &pd->image),
+                                    &my_image),
       TALER_PQ_result_spec_json ("address",
-                                 &pd->address),
+                                 &my_address),
       GNUNET_PQ_result_spec_timestamp ("next_restock",
                                        &pd->next_restock),
       GNUNET_PQ_result_spec_uint32 ("minimum_age",
@@ -111,14 +119,32 @@ TMH_PG_lookup_product (void *cls,
       GNUNET_PQ_result_spec_array_uint64 (pg->conn,
                                           "categories",
                                           num_categories,
-                                          categories),
+                                          &my_categories),
       GNUNET_PQ_result_spec_end
     };
+    enum GNUNET_DB_QueryStatus qs;
 
     check_connection (pg);
-    return GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
-                                                     "lookup_product",
-                                                     params,
-                                                     rs);
+    qs = GNUNET_PQ_eval_prepared_singleton_select (pg->conn,
+                                                   "lookup_product",
+                                                   params,
+                                                   rs);
+    pd->description = my_description;
+    pd->description_i18n = my_description_i18n;
+    pd->unit = my_unit;
+    pd->taxes = my_taxes;
+    pd->image = my_image;
+    pd->address = my_address;
+    *categories = my_categories;
+    /* Clear original pointers to that cleanup_result doesn't squash them */
+    my_description = NULL;
+    my_description_i18n = NULL;
+    my_unit = NULL;
+    my_taxes = NULL;
+    my_image = NULL;
+    my_address = NULL;
+    my_categories = NULL;
+    GNUNET_PQ_cleanup_result (rs);
+    return qs;
   }
 }
