@@ -30,6 +30,9 @@
  *
  * @param cls closure
  * @param instance_id instance to lookup products for
+ * @param offset transfer_serial number of the transfer we want to offset from
+ * @param limit number of entries to return, negative for descending,
+ *                positive for ascending
  * @param cb function to call on all products found
  * @param cb_cls closure for @a cb
  * @return database result code
@@ -37,6 +40,8 @@
 enum GNUNET_DB_QueryStatus
 TMH_PG_lookup_products (void *cls,
                         const char *instance_id,
+                        uint64_t offset,
+                        int64_t limit,
                         TALER_MERCHANTDB_ProductsCallback cb,
                         void *cb_cls);
 
