@@ -31,6 +31,7 @@
 #include <taler/taler_mhd_lib.h>
 #include "taler_merchantdb_plugin.h"
 #include "pg_helper.h"
+#include "pg_gc.h"
 #include "pg_insert_otp.h"
 #include "pg_get_kyc_status.h"
 #include "pg_get_kyc_limits.h"
@@ -630,7 +631,8 @@ libtaler_plugin_merchantdb_postgres_init (void *cls)
     = &TMH_PG_insert_issued_token;
   plugin->lookup_spent_tokens_by_order
     = &TMH_PG_lookup_spent_tokens_by_order;
-
+  plugin->gc
+    = &TMH_PG_gc;
 
   return plugin;
 }
