@@ -70,12 +70,12 @@ parse_account_history (struct TALER_MERCHANT_BANK_CreditHistoryHandle *hh,
                        const json_t *history)
 {
   const json_t *history_array;
-  const char *credit_account_uri;
+  struct TALER_FullPayto credit_account_uri;
   struct GNUNET_JSON_Specification spec[] = {
     GNUNET_JSON_spec_array_const ("incoming_transactions",
                                   &history_array),
-    GNUNET_JSON_spec_string ("credit_account",
-                             &credit_account_uri),
+    TALER_JSON_spec_full_payto_uri ("credit_account",
+                                    &credit_account_uri),
     GNUNET_JSON_spec_end ()
   };
 
@@ -101,8 +101,8 @@ parse_account_history (struct TALER_MERCHANT_BANK_CreditHistoryHandle *hh,
                                &row_id),
       GNUNET_JSON_spec_string ("subject",
                                &td.wire_subject),
-      GNUNET_JSON_spec_string ("debit_account",
-                               &td.debit_account_uri),
+      TALER_JSON_spec_full_payto_uri ("debit_account",
+                                      &td.debit_account_uri),
       GNUNET_JSON_spec_end ()
     };
     json_t *transaction = json_array_get (history_array,
