@@ -169,7 +169,7 @@ struct TALER_TESTING_Command
 TALER_TESTING_cmd_merchant_post_account (
   const char *label,
   const char *merchant_url,
-  const char *payto_uri,
+  struct TALER_FullPayto payto_uri,
   const char *credit_facade_url,
   const json_t *credit_facade_credentials,
   unsigned int http_status);
@@ -613,7 +613,7 @@ TALER_TESTING_cmd_merchant_post_orders3 (
  * @param merchant_url base URL of the merchant serving
  *        the proposal request.
  * @param http_status expected HTTP status.
- * @param token_family_reference label of the POST /tokenfamilies cmd.
+ * @param token_family_slug slug of the token family to use
  * @param num_inputs number of input tokens.
  * @param num_outputs number of output tokens.
  * @param order_id the name of the order to add.
@@ -629,7 +629,7 @@ TALER_TESTING_cmd_merchant_post_orders_choices (
   const struct GNUNET_CONFIGURATION_Handle *cfg,
   const char *merchant_url,
   unsigned int http_status,
-  const char *token_family_reference,
+  const char *token_family_slug,
   unsigned int num_inputs,
   unsigned int num_outputs,
   const char *order_id,
@@ -852,7 +852,7 @@ TALER_TESTING_cmd_merchant_get_order (
  * @param wired whether the order has been wired or not.
  * @param transfers NULL-terminated list of labels (const char *) of
  *        wire transfers (commands) we expect to be aggregated in the order
- *        (assuming @a http_code is #MHD_HTTP_OK). If @e paid is fale, this
+ *        (assuming @a http_code is #MHD_HTTP_OK). If @e paid is false, this
  *        parameter is ignored.
  * @param refunded whether the order has been refunded.
  * @param refunds NULL-terminated list of labels (const char *) of
@@ -1167,7 +1167,7 @@ struct TALER_TESTING_Command
 TALER_TESTING_cmd_merchant_post_transfer (
   const char *label,
   const struct TALER_BANK_AuthenticationData *auth,
-  const char *payto_uri,
+  struct TALER_FullPayto payto_uri,
   const char *merchant_url,
   const char *credit_amount,
   unsigned int http_code,
@@ -1191,7 +1191,7 @@ struct TALER_TESTING_Command
 TALER_TESTING_cmd_merchant_post_transfer2 (
   const char *label,
   const char *merchant_url,
-  const char *payto_uri,
+  struct TALER_FullPayto payto_uri,
   const char *credit_amount,
   const char *wtid,
   const char *exchange_url,
@@ -1225,11 +1225,12 @@ TALER_TESTING_cmd_merchant_post_transfer_set_serial (
  * @return the command.
  */
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_get_transfers (const char *label,
-                                          const char *merchant_url,
-                                          const char *payto_uri,
-                                          unsigned int http_code,
-                                          ...);
+TALER_TESTING_cmd_merchant_get_transfers (
+  const char *label,
+  const char *merchant_url,
+  struct TALER_FullPayto payto_uri,
+  unsigned int http_code,
+  ...);
 
 
 /**
@@ -1259,6 +1260,7 @@ TALER_TESTING_cmd_merchant_delete_transfer (const char *label,
  * @param h_wire_ref label of command with a merchant wire hash trait
  *        of the bank account to check KYC for; NULL to check all accounts
  * @param exchange_url base URL of the exchange to check KYC status for
+ * @param lpt target for long polling
  * @param expected_http_status expected HTTP status
  * @param expected_kyc_state expected KYC state (only effective if @e expected_http_status is #MHD_HTTP_OK/#MHD_HTTP_ACCEPTED)
  * @return the command
@@ -1270,6 +1272,7 @@ TALER_TESTING_cmd_merchant_kyc_get (
   const char *instance_id,
   const char *h_wire_ref,
   const char *exchange_url,
+  enum TALER_EXCHANGE_KycLongPollTarget lpt,
   unsigned int expected_http_status,
   bool expected_kyc_state);
 
@@ -1854,7 +1857,7 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
 #define TALER_MERCHANT_TESTING_INDEXED_TRAITS(op) \
         op (coin_reference, const char) \
         op (paths, const char) \
-        op (payto_uris, const char) \
+        op (payto_uris, const struct TALER_FullPayto) \
         op (h_wires, const struct TALER_MerchantWireHashP) \
         op (amounts, const struct TALER_Amount)         \
         op (urls, const char) \
@@ -1864,8 +1867,8 @@ TALER_TESTING_cmd_checkserver2 (const char *label,
         op (http_body_size, const size_t)   \
         op (planchet_secrets, const struct TALER_PlanchetMasterSecretP)   \
         op (token_priv, const struct TALER_TokenUsePrivateKeyP)   \
-        op (token_issue_sig, const struct TALER_TokenIssueSignatureP)   \
-        op (token_issue_pub, const struct TALER_TokenIssuePublicKeyP)
+        op (token_issue_sig, const struct TALER_TokenIssueSignature)   \
+        op (token_issue_pub, const struct TALER_TokenIssuePublicKey)
 
 
 TALER_MERCHANT_TESTING_SIMPLE_TRAITS (TALER_TESTING_MAKE_DECL_SIMPLE_TRAIT)
