@@ -76,7 +76,7 @@ run (void *cls,
     return;
   }
   if (NULL == instance)
-    instance = GNUNET_strdup ("default");
+    instance = GNUNET_strdup ("admin");
   cfg = GNUNET_CONFIGURATION_dup (config);
   if (NULL ==
       (plugin = TALER_MERCHANTDB_plugin_load (cfg)))
