@@ -207,9 +207,9 @@ run (void *cls,
 {
   struct TALER_TESTING_Command get_private_order_id[] = {
     TALER_TESTING_cmd_merchant_post_instances (
-      "instance-create-default",
+      "instance-create-admin",
       merchant_url,
-      "default",
+      "admin",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
       "instance-create-default-account",
@@ -256,9 +256,9 @@ run (void *cls,
       "4",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_purge_instance (
-      "purge-default",
+      "purge-admin",
       merchant_url,
-      "default",
+      "admin",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_end ()
   };
@@ -1850,7 +1850,7 @@ run (void *cls,
     TALER_TESTING_cmd_merchant_post_instances (
       "instance-create-default-setup",
       merchant_url,
-      "default",
+      "admin",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
       "instance-create-default-account",
@@ -1979,12 +1979,12 @@ run (void *cls,
     TALER_TESTING_cmd_merchant_purge_instance (
       "instance-purge-default-middle",
       merchant_url,
-      "default",
+      "admin",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_instances (
       "instance-create-default-after-purge",
       merchant_url,
-      "default",
+      "admin",
       MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
       "instance-create-default-account-after-purge",
