@@ -331,9 +331,9 @@ run (void *cls,
                                     NULL,
                                     true,
                                     true),
-    TALER_TESTING_cmd_merchant_post_instances ("instance-create-default",
+    TALER_TESTING_cmd_merchant_post_instances ("instance-create-admin",
                                                twister_merchant_url,
-                                               "default",
+                                               "admin",
                                                MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
       "instance-create-default-account",
@@ -404,12 +404,10 @@ run (void *cls,
                                           "EUR:5",
                                           "EUR:4.99",
                                           NULL),
-    TALER_TESTING_cmd_malform_response ("malform-abort-merchant-exchange",
-                                        PROXY_EXCHANGE_config_file),
     TALER_TESTING_cmd_merchant_order_abort ("pay-abort-1",
                                             merchant_url,
                                             "deposit-2",
-                                            MHD_HTTP_BAD_GATEWAY),
+                                            MHD_HTTP_OK),
     TALER_TESTING_cmd_end ()
   };
 
