@@ -29,7 +29,7 @@ STATUS=$(curl -H "Content-Type: application/json" -X OPTIONS \
 
 if [ "$STATUS" != "204" ]
 then
-    exit_fail "Expected 204 when default instance does not exist yet. got: $STATUS"
+    exit_fail "Expected 204 when admin instance does not exist yet. got: $STATUS"
 fi
 
 STATUS=$(curl -H "Content-Type: application/json" -X GET \
@@ -39,13 +39,13 @@ STATUS=$(curl -H "Content-Type: application/json" -X GET \
 
 if [ "$STATUS" != "404" ]
 then
-    exit_fail "Expected 404 when the default instance is not yet created. got: $STATUS"
+    exit_fail "Expected 404 when the admin instance is not yet created. got: $STATUS"
 fi
 
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
     http://localhost:9966/management/instances \
-    -d '{"auth":{"method":"token","token":"secret-token:other_secret"},"id":"default","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 3600000000},"default_pay_delay":{"d_us": 3600000000}}' \
+    -d '{"auth":{"method":"token","token":"secret-token:other_secret"},"id":"admin","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 3600000000},"default_pay_delay":{"d_us": 3600000000}}' \
     -w "%{http_code}" -s -o /dev/null)
 
 if [ "$STATUS" != "204" ]
@@ -59,7 +59,7 @@ STATUS=$(curl -H "Content-Type: application/json" -X GET \
 
 if [ "$STATUS" != "401" ]
 then
-    exit_fail "Expected 401 without the token for the list of product when the default instance was created. got: $STATUS"
+    exit_fail "Expected 401 without the token for the list of product when the admin instance was created. got: $STATUS"
 fi
 
 STATUS=$(curl -H "Content-Type: application/json" -X GET \
@@ -69,7 +69,7 @@ STATUS=$(curl -H "Content-Type: application/json" -X GET \
 
 if [ "$STATUS" != "200" ]
 then
-    exit_fail "Expected 200 for the list of product when the default instance was created. got: $STATUS"
+    exit_fail "Expected 200 for the list of product when the admin instance was created. got: $STATUS"
 fi
 
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
@@ -121,7 +121,7 @@ STATUS=$(curl -H "Content-Type: application/json" -X GET \
 
 if [ "$STATUS" != "404" ]
 then
-    exit_fail "Expected 404 when trying to list the product and the default instance was deleted. got: $STATUS"
+    exit_fail "Expected 404 when trying to list the product and the admin instance was deleted. got: $STATUS"
 fi
 
 echo "Test PASSED"
