@@ -99,7 +99,7 @@ echo " OK"
 # CREATE INSTANCE FOR TESTING
 #
 
-echo -n "Configuring merchant default instance ..."
+echo -n "Configuring merchant admin instance ..."
 if [ 1 = "$USE_FAKEBANK" ]
 then
     TOR_PAYTO="payto://x-taler-bank/localhost/tor?receiver-name=tor"
@@ -117,7 +117,7 @@ fi
 STATUS=$(curl -H "Content-Type: application/json" -X POST \
     -H 'Authorization: Bearer secret-token:super_secret' \
     http://localhost:9966/management/instances \
-    -d '{"auth":{"method":"external"},"id":"default","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 50000000},"default_pay_delay":{"d_us": 60000000}}' \
+    -d '{"auth":{"method":"external"},"id":"admin","name":"default","user_type":"business","address":{},"jurisdiction":{},"use_stefan":true,"default_wire_transfer_delay":{"d_us" : 50000000},"default_pay_delay":{"d_us": 60000000}}' \
     -w "%{http_code}" -s -o /dev/null)
 
 if [ "$STATUS" != "204" ]
@@ -273,7 +273,7 @@ set +e
 echo -n "Notifying merchant of correct wire transfer, but on wrong instance..."
 
 #issue 6912
-#here we are notifying the transfer into a wrong instance (default) and the payto_uri of the default instance
+#here we are notifying the transfer into a wrong instance (admin) and the payto_uri of the admin instance
 STATUS=$(curl 'http://localhost:9966/private/transfers' \
     -d "{\"credit_amount\":\"$CREDIT_AMOUNT\",\"wtid\":\"$WTID\",\"payto_uri\":\"$TOR_PAYTO\",\"exchange_url\":\"$WURL\"}" \
     -m 3 \
@@ -287,7 +287,7 @@ fi
 echo " OK"
 
 
-echo -n "Fetching wire transfers of DEFAULT instance ..."
+echo -n "Fetching wire transfers of ADMIN instance ..."
 
 STATUS=$(curl 'http://localhost:9966/private/transfers' \
     -w "%{http_code}" -s -o "$LAST_RESPONSE")
