@@ -104,18 +104,20 @@ struct PostInstancesState
  * @param hr response being processed
  */
 static void
-post_instances_cb (void *cls,
-                   const struct TALER_MERCHANT_HttpResponse *hr)
+post_instances_cb (
+  void *cls,
+  const struct TALER_MERCHANT_HttpResponse *hr)
 {
   struct PostInstancesState *pis = cls;
 
   pis->iph = NULL;
   if (pis->http_status != hr->http_status)
   {
-    TALER_TESTING_unexpected_status_with_body (pis->is,
-                                               hr->http_status,
-                                               pis->http_status,
-                                               hr->reply);
+    TALER_TESTING_unexpected_status_with_body (
+      pis->is,
+      hr->http_status,
+      pis->http_status,
+      hr->reply);
     TALER_TESTING_interpreter_fail (pis->is);
     return;
   }
@@ -152,9 +154,10 @@ post_instances_cb (void *cls,
  * @param is interpreter state.
  */
 static void
-post_instances_run (void *cls,
-                    const struct TALER_TESTING_Command *cmd,
-                    struct TALER_TESTING_Interpreter *is)
+post_instances_run (
+  void *cls,
+  const struct TALER_TESTING_Command *cmd,
+  struct TALER_TESTING_Interpreter *is)
 {
   struct PostInstancesState *pis = cls;
 
@@ -283,10 +286,11 @@ TALER_TESTING_cmd_merchant_post_instances2 (
 
 
 struct TALER_TESTING_Command
-TALER_TESTING_cmd_merchant_post_instances (const char *label,
-                                           const char *merchant_url,
-                                           const char *instance_id,
-                                           unsigned int http_status)
+TALER_TESTING_cmd_merchant_post_instances (
+  const char *label,
+  const char *merchant_url,
+  const char *instance_id,
+  unsigned int http_status)
 {
   return TALER_TESTING_cmd_merchant_post_instances2 (
     label,
