@@ -278,7 +278,7 @@ TALER_MERCHANT_parse_choice_output (
     }
   case TALER_MERCHANT_CONTRACT_OUTPUT_TYPE_DONATION_RECEIPT:
     {
-      const json_t *donau_urls;
+      const json_t *donau_urls = NULL;
       struct GNUNET_JSON_Specification spec[] = {
         GNUNET_JSON_spec_mark_optional (
           TALER_JSON_spec_amount_any ("amount",
